@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/06/24 11:13:32 $
-# $Revision: 1.18.1.164 $
+# $Date: 1998/07/10 11:05:07 $
+# $Revision: 1.18.1.167 $
 #
 #
 package provide zircon 1.18
@@ -202,11 +202,7 @@ proc channel_setTopic {this string} {
     $w configure -state normal
     $w delete 1.0 end
     insertText $this $w $string {}
-    switch disabled $state {
-	$w configure -state disabled -relief raised
-    } default {
-	$w configure -relief sunken
-    }
+    $this topicState $state
 }
 #
 proc channel_changeMode {this mode} {
@@ -666,7 +662,7 @@ proc makeCText {this net w chan rchan idx cdx look} {
     set cl 0
     set rs 0
     foreach x $look {
-	switch [lindex $x 0] {
+	switch -- [lindex $x 0] {
 	nowrap {
 		scrollbar -orient horizontal $f.hs -command "$ot xview"
 		$ot configure -wrap none -xscrollcommand "$f.hs set"
@@ -1000,13 +996,13 @@ proc makeCControl {this net w chan rchan idx cdx look} {
 proc rowHide {this net w idx} {
     grid remove $w.r$idx
     if {![winfo exists $w.phide]} {
-        grid [frame $w.phide -borderwidth 0 -relief flat] \
+	grid [frame $w.phide -borderwidth 0 -relief flat] \
 	  -row 0 -column 0 -sticky nw
     }
     grid [frame $w.phide.u$idx -relief raised -borderwidth 2] \
       -row 0 -column $idx -ipady 3 -ipadx 10 -sticky w
     bind $w.phide.u$idx <1> "
-        destroy %W
+	destroy %W
 	grid $w.r$idx
 	switch {} \[winfo children $w.phide\] { destroy $w.phide }
     "
@@ -1096,9 +1092,10 @@ proc channel_cmdState {this} {
 	set st normal
     }
     catch {$w.action configure -state $st}
-    set mn $w.channel.menu
-    foreach x {notice messages draw ctcp sound} {
-	catch {$mn entryconfigure [$mn index [trans $x]] -state $st}
+    if {[winfo exists [set mn $w.channel.menu]]} {
+	foreach x {notice messages draw ctcp sound} {
+	    $mn entryconfigure [$mn index [trans $x]] -state $st
+	}
     }
 }
 #
@@ -1278,15 +1275,20 @@ proc channel_clear {this hist} {
 	$t delete 1.0 end
 	$t configure -state disabled
     } {
-	$t xview moveto 0
-	$t yview moveto 1.0
-	return
-	set posn [$t yview]
-	regexp {(.*)\..*} [$t index end] m ln
+	if {![tk_dialog .@clr$this [trans clear] "Due to a change in the way that\
+	tk handles text windows it is no longer possible to make the clear function\
+	clear only the viewable area.
+	
+You can however clear the window AND ALL THE SCROLLBACK BUFFER.
+	
+Click \"Yes\" if you wish to do this.
+
+If you do not want to see this message again Shift-Click on the Clear button" info 0 \
+	[trans Yes] [trans No]]} {
+	}
 	$t configure -state normal
-	while {$st > 0} { $t insert end "\n" ; incr st -1 }
+	$t delete 1.0 end
 	$t configure -state disabled
-	$t see end
     }
 }
 #
@@ -1346,18 +1348,27 @@ proc channel_markV {this usr} { $this Vmarker $usr speaker 1 }
 #
 proc channel_unmarkV {this usr} { $this Vmarker $usr {} 0 }
 #
+proc channel_topicState {this state} {
+    switch {} [set win [$this window]] return
+    if {![winfo exists $win.topic]} return
+    $win.topic.label configure -state $state
+    $win.topic.entry configure -state $state
+    switch $state disabled {
+	$win.topic.entry configure -relief sunken
+    } normal {
+	$win.topic.entry configure -relief raised
+    }
+}
+#
 proc channel_flag {this state} {
     if {![$this active]} return
     set win [$this window]
     foreach w {mode channel action} { catch {$win.$w conf -state $state} }
-    catch {
-	$win.topic.label conf -state disabled
-	$win.topic.entry conf -state disabled
+    $this topicState disabled
+    if {[winfo exists [set uu [$this ufrm].userBtn]]} {
+	foreach w [winfo children $uu] {$w conf -state $state}
     }
-    catch {
-	foreach w [winfo children [$this ufrm].userBtn] {$w conf -state $state}
-    }
-    catch {
+    if {[winfo exists $win.users.menu]} {
 	set l [$win.users.menu index last]
 	while {$l > 2} {
 	    $win.users.menu entryconfigure $l -state $state
@@ -1367,10 +1378,8 @@ proc channel_flag {this state} {
     switch normal $state {
 	foreach w [$this splitusers] {
 	    catch {[$this ufrm].userBtn.$n conf -state disabled}
-	    catch {
-		if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
-		    $w.users.menu entryconfigure $x -state disabled
-		}
+	    if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
+		$w.users.menu entryconfigure $x -state disabled
 	    }
 	}
     } default {
@@ -1410,11 +1419,9 @@ proc channel_nickChange {this usr nnk} {
 		wsortIns $this $uf.userBtn $nnk $usr
 		$uf.userBtn.$usr configure -fg $fg -bg $bg -font $ft
 	    }
-	    catch {
-		if {[set x [indexHack $w.users.menu [$usr name] 4]] >=0} {
-		    $w.users.menu delete $x
-		    sortIns $this $nnk $usr $w.users.menu
-		}
+	    if {[set x [indexHack $w.users.menu [$usr name] 4]] >=0} {
+		$w.users.menu delete $x
+		sortIns $this $nnk $usr $w.users.menu
 	    }
 	}
     }
@@ -1467,8 +1474,8 @@ proc wsortIns {chan win un usr args} {
     set top text
     set wd [$win cget -width]
     switch nil [set fr [$usr fobj]] {} default {
-        switch {} [set fg [$fr images]] {} default {
-           set top image
+	switch {} [set fg [$fr images]] {} default {
+	   set top image
 	   set img [lindex $fg 0]
 	   set wd {}
 	   switch -glob -- $txt {
@@ -1502,17 +1509,17 @@ proc wsortIns {chan win un usr args} {
 #
 proc channel_addUser {this usr op sp} {
     upvar #0 $this cdata
-    lclTrace $this Op,$usr
-    set cdata(Op,$usr) $op
+    set marking {}
     lclTrace $this Spk,$usr
-    set cdata(Spk,$usr) $sp
+    if {[set cdata(Spk,$usr) $sp]} { set marking speaker }
+    lclTrace $this Op,$usr
+    if {[set cdata(Op,$usr) $op]} { set marking operator }
     set net $cdata(net)
     set w $cdata(window)
     set un [$usr name]
     set jn 1
     listincl cdata(users) $usr
-    catch {
-	set win [$this ufrm].userBtn
+    if {[winfo exists [set win [$this ufrm].userBtn]]} {
 	set wnk $win.$usr
 	if {![winfo exists $wnk]} {
 	    wsortIns $this $win $un $usr
@@ -1520,11 +1527,9 @@ proc channel_addUser {this usr op sp} {
 	    set jn 0
 	}
 	$wnk configure -state normal
-	if {$op} { markButton $net $wnk operator } \
-	elseif {$sp} { markButton $net $wnk speaker } { markButton $net $wnk {} }
+	markButton $net $wnk $marking
     }
-    catch {
-	set w $w.users.menu
+    if {[winfo exists [set w $w.users.menu]]} {
 	if {[$net me $usr]} {
 	    if {![winfo exists $w.$usr]} {
 		$w insert 3 cascade -label $un -menu $w.$usr
@@ -1537,8 +1542,7 @@ proc channel_addUser {this usr op sp} {
 	} {
 	    $w entryconfigure $x -state normal
 	}
-	if {$op} { markEntry $w $x operator } \
-	elseif {$sp} { markEntry $w $x speaker } { markEntry $w $x {} }
+	markEntry $w $x $marking
     }
     $this makeTag $usr
     if {$jn} { $usr join $this }
@@ -1636,13 +1640,7 @@ proc channel_mode {this vals prefix} {
 			if {![$this operator]} {
 			    set st [expr {$x ? {disabled} : {normal}}]
 			    switch {} [set w $cdata(window)] {} default {
-				$w.topic.label conf -state $st
-				$w.topic.entry conf -state $st
-				switch $st disabled {
-				    $w.topic.entry configure -relief sunken
-				} default {
-				    $w.topic.entry configure -relief raised
-				}
+				$this topicState $st
 			    }
 			}
 			handleOn $net MODE [list [$this name] ${flag}t]
@@ -1680,10 +1678,7 @@ proc channel_mode {this vals prefix} {
     }
     if {$cdata(modewait)} {
 	set cdata(modewait) 0
-	if {!$cdata(t)  && ![string match {} [set w $cdata(window)]]} {
-	    catch {$w.topic.label configure -state normal}
-	    catch {$w.topic.entry configure -state normal -relief raised}
-	}
+	if {!$cdata(t)} { $this topicState normal }
     }
 }
 #
@@ -1699,8 +1694,7 @@ proc channel_opItems {this state} {
 	    setState $name chanop $state
 	}
     }
-    if {[$this isa Channel]} {
-	if {![winfo exists [set mn $win.mode.menu]]} return
+    if {[$this isa Channel] && [winfo exists [set mn $win.mode.menu]]} {
 	set vl [$mn index [trans ban]]
 	incr vl
 	set last [$mn index last]
@@ -1710,8 +1704,7 @@ proc channel_opItems {this state} {
 	}
 	upvar #0 $this cdata
 	if {![string compare $state normal] || $cdata(t)} {
-	    catch {$win.topic.entry conf -state $state}
-	    catch {$win.topic.label conf -state $state}
+	    $this topicState $state
 	}
 	$this cmdState
     }
@@ -1860,11 +1853,13 @@ proc indexHack {w nk start} {
 #
 # Do non-pattern based index matching....
 #
-    set x [$w index end]
-    set i $start
-    while {$i <= $x} {
-	switch -- [$w entrycget $i -label] $nk - @$nk - +$nk - @+$nk {return $i}
-	incr i
+    if {[winfo exists $w]} {
+	set x [$w index end]
+	set i $start
+	while {$i <= $x} {
+	    switch -- [$w entrycget $i -label] $nk - @$nk - +$nk - @+$nk {return $i}
+	    incr i
+	}
     }
     return -1
 
