@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Consts.tcl,v $
-# $Date: 1998/06/07 19:13:05 $
-# $Revision: 1.18.1.3 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Consts.tcl,v $
+# $Date: 1998/07/09 11:14:51 $
+# $Revision: 1.18.1.4 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -212,19 +212,25 @@ proc InitConsts {} {
     # Configuration panel stuff
     #
     array set cVars {
-    Nicknames		{nicks}
-    IRCNames		{ircnames}
+    Nicknames	[list nicks]
+    IRCNames	[list ircnames]
     Servers	{}
     DCC		{}
     Messages	{}
     Notices	{}
     Chat	{}
     Channels	{}
-    Friends	{showFriends friendsOn}
-    Ignores	{ignores}
-    Info	{showLocal showPublic showPrivate topicOnly minMembers  noConfirm\
-      toInfo popInfo verboseCTCP helpService  noPopup noRefresh killPath\
-      listPattern topicPattern  notifyInterval}
+    Friends	[list showFriends friendsOn]
+    Ignores	[list ignores]
+    Info	[list showLocal showPublic showPrivate topicOnly minMembers \
+    	noConfirm toInfo helpService listPattern topicPattern \
+	notifyInterval sorted nocase]
+    }
+    global Configure.Net
+    foreach {nm vl} [array get Configure.Net] {
+        switch bool [lindex $vl 0] {
+	    lappend cVars(Info) $nm
+	}
     }
     #
     array set confData {
