@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/06/24 11:13:36 $
-# $Revision: 1.18.1.96 $
+# $Date: 1998/07/10 11:05:10 $
+# $Revision: 1.18.1.98 $
 #
 #
 package provide zircon 1.18
@@ -23,6 +23,12 @@ proc control_lag {this secs} {
     $frm.lag configure -text "$secs secs"
 }
 #
+proc control_lagClear {this} {
+    if {[winfo exists [set frm [winfo parent [$this window]].exp.lag]]} {
+        $frm configure -text {}
+    }
+}
+#
 proc control_pickServer {this srv} { [$this net] changeServer $srv }
 #
 proc control_showServer {this srv args} {
@@ -181,6 +187,7 @@ proc Control {args} {
     button $ctl.invisible -text [trans invisible] -command "$net toggleFlag invisible"
     $this NNSBuild $ctl Nickname nickname [$net nicks] $net  $ctl.invisible
     nickKeys $net $ctl.nickname
+    set cdata(nfg) [$ctl.nickname cget -foreground]
     if {[$net ircIImode]} { set im $zII } { set im $zNOII }
     button $ctl.ii -command "ntoggleII $net $ctl.ii" -image $im
     set en [$this NNSBuild $ctl IRCName ircname [$net ircnames] $net $ctl.ii]
@@ -634,10 +641,11 @@ proc control_flagState {this state} {
 	foreach y [winfo children $x] {catch {$y configure -state $state }}
 	catch {$x configure -state $state}
     }
-    switch normal $state {} default {
+    switch $state normal {} disabled {
 	foreach x {server nickname lnickname ircname lircname port quit} {
 	    $ctl.$x configure -state normal
 	}
+	$this lagClear
     }
     [$this friends] flagState $state
 }
@@ -714,8 +722,6 @@ proc ntoggleII {net win} {
 }
 #
 proc control_flagNick {this} {
-    upvar #0 $this cdata
-    set cdata(nfg) [[$this window].nickname cget -foreground]
     [$this window].nickname configure -foreground red
 }
 #
