@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Look.tcl,v $
-# $Date: 1998/06/11 08:42:46 $
-# $Revision: 1.18.1.19 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Look.tcl,v $
+# $Date: 1998/07/09 14:44:08 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -202,4 +202,16 @@ proc saveShare {desc net} {
 	}
     }
 }
+#
+proc remShareLook {net} {
+    foreach var {Share Look} {
+        upvar #0 $var gv
+	foreach {x y} [array get gv] {
+	    switch -- $net [lindex $y 0] {
+	        unset gv($x)
+	    }
+	}
+    }
+    
+}
 
