@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/06/25 10:55:52 $
-# $Revision: 1.18.1.143 $
+# $Date: 1998/07/10 11:05:13 $
+# $Revision: 1.18.1.148 $
 #
 package provide zircon 1.18
 #
@@ -196,6 +196,7 @@ proc net_flagControl {this state} {
 #
 proc net_finfo {this} {
     upvar #0 $this ndata
+    switch {} $ndata(control) { return nil }
     return [$ndata(control) friends]
 }
 #
@@ -203,7 +204,9 @@ proc net_setupUsers {this} {
     set frnd [$this finfo]
     foreach frd [$this friends] {
 	if {[$this friendsOn]} { $frd configure -notify 1 }
-	if {![$this friendsOn] || [$frd ison]} { $frnd add $frd}
+	switch nil $frnd {} default {
+	    if {![$this friendsOn] || [$frd ison]} { $frnd add $frd}
+	}
     }
 }
 #
@@ -309,21 +312,21 @@ proc net_startIRC {this srv args} {
 		$this fast
 		update
 		set rtc 2
-		continue
+	    } {
+		$this fast
+		fileevent $sock writable "sconf $sock [list $enc]; $this afterCon $sock"
+		$ctl setQuit abort "$this abort $sock"
+		set connected($this) 0
+		vwait connected($this)
+		set rtc $connected($this)
+		unset connected($this)
+		if {$rtc < 2} {
+		    $ctl setQuit close "$this quit"
+		    return 1
+		}
+		$ctl setQuit open "$ctl open"
+		$ctl setOpen $ost
 	    }
-	    $this fast
-	    fileevent $sock writable "sconf $sock [list $enc]; $this afterCon $sock"
-	    $ctl setQuit abort "$this abort $sock"
-	    set connected($this) 0
-	    vwait connected($this)
-	    set rtc $connected($this)
-	    unset connected($this)
-	    if {$rtc < 2} {
-		$ctl setQuit close "$this quit"
-		return 1
-	    }
-	    $ctl setQuit open "$ctl open"
-	    $ctl setOpen $ost
 	    if {$rtc == 2} {
 	    	$this inform {Connection attempt failed}
 		retitleFrame [MainControl] $this [$this name] 1
@@ -333,16 +336,16 @@ proc net_startIRC {this srv args} {
 		retitleFrame [MainControl] $this [$this name]
 		retitleFrame [MainInfo] [$this info] [$this name]
 	    }
+	    switch {} [$srv nextPort] break
 	}
 	$ctl showServer $srv [lindex $ports 0]
 	if {$noret} { return 0}
 	if {$rtc == 2} {
 	    if {![askUser NOCON [trans connect] \
 	      "Cannot connect to any ports of $server.\nTry again?"]} {
-	        return 0
+		return 0
 	    }
 	}
-	switch {} [$srv nextPort] break
     }
 }
 #
@@ -668,7 +671,7 @@ proc net_pingTest {this} {
 proc net_handlePong {this} {
     upvar #0 $this ndata
     if {$ndata(lagmeter)} {
-        [$this control] lag [expr {[clock seconds] - $ndata(pinged)}]
+	[$this control] lag [expr {[clock seconds] - $ndata(pinged)}]
     }
     set ndata(pinged) 0
 }
@@ -801,7 +804,7 @@ proc net_error {this prefix param pargs} {
     } {
 	set msg "Closing connection to $hst, ERROR : $param"
     }
-    $this close $msg
+    $this close $msg 1
 }
 #
 proc net_sysQ {this req} {
@@ -828,6 +831,7 @@ proc net_delete {this} {
     global znetList
     safeUnset [list XTO([string tolower [$this name]])] OType($this) $this
     listkill znetList $this
+    remShareLook $this
     rename $this {}
 }
 #
