@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Split.tcl,v $
-# $Date: 1998/06/08 21:37:37 $
-# $Revision: 1.18.1.3 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Split.tcl,v $
+# $Date: 1998/06/12 15:04:25 $
+# $Revision: 1.18.1.6 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -79,7 +79,7 @@ proc channel_userSplit {this usr split} {
 		$w.users.menu entryconfigure $x -state disabled
 	    }
 	}
-	catch {[$this uFrm].userBtn.$usr conf -state disabled}
+	catch {[$this ufrm].userBtn.$usr conf -state disabled}
 	uplevel #0 listincl ${this}(splitusers) $usr
 	$this optText LOST "*** [$usr name] is lost - ($split)"
     } \
@@ -87,3 +87,36 @@ proc channel_userSplit {this usr split} {
         switch {} [$this mwin] {} default {[$this mwin] setState $usr disabled}
     }
 }
+#
+proc net_newSplit {this split} {
+    global Split TSplit Heal
+    upvar #0 $this ndata
+    $ndata(info) optText SPLIT "*** Netsplit - $split"
+    set TSplit($split) [after 600000 $this cleanSplit "{$split}"]
+    catch {after cancel $Heal($split) ; unset Heal($split)}
+    handleOn $this SPLIT $split
+    lappend ndata(splits) [list $split]
+}
+#
+proc net_cleanSplit {this h} {
+    global Split Heal TSplit
+    upvar #0 $this ndata
+    if {[info exists Split($h)]} {
+	set frnd [$this finfo]
+	foreach user $Split($h) {
+	    if {[catch {set nk [$user name]}]} continue
+	    foreach x {Chat Message Notice} {
+		switch nil [set msg [$x :: find $nk $this]] {} default {
+		    $msg heal
+		}
+	    }
+	    foreach id [$this channels] { $id remove $user }
+	    $frnd remove [$user fobj]
+	    $user deref
+	}
+	unset Split($h)
+	listkill ndata(splits) [list $h]
+    }
+    catch { after cancel $TSplit($h) ; unset TSplit($h) }
+    catch { after cancel $Heal($h) ; unset Heal($h) }
+}
