@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Window.tcl,v $
-# $Date: 1998/06/22 14:37:03 $
-# $Revision: 1.18.1.34 $
+# $Date: 1998/07/09 11:15:00 $
+# $Revision: 1.18.1.35 $
 #
 package provide zircon 1.18
 #
@@ -139,19 +139,6 @@ proc window_withdraw {this} {
     foreach x [$this children] {[lindex $x 0] popdown }
 }
 #
-proc checkMainClose {} {
-    global zWClose zWInc zWList
-    set val 0
-    foreach x $zWList {
-        if {[$x closetime] != 0} {
-	    if {$val == 0 || [$x closetime] < $val} {
-	        set val [$x closetime]
-	    }
-	}
-    }
-    if {$val > 0} { set zWInc $val } { set zWInc 30000 }
-}
-#
 proc window_configure {this args} {
     upvar #0 $this wdata
     foreach {name val} $args {
@@ -159,6 +146,7 @@ proc window_configure {this args} {
 	switch -glob -- $name {
 	-closetime {
 		if {$val > 0} {
+		    if {$val < 10000} { set val 10000 }
 		    if {$val < $wdata(closecount)} { set wdata(closecount) $val}
 		    set wdata(closetime) $val
 		} elseif {$val == 0} {
