@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/initial.tcl,v $
-# $Date: 1998/05/28 09:33:21 $
-# $Revision: 1.18.1.169 $
+# $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
+# $Date: 1998/07/09 14:44:15 $
+# $Revision: 1.18.1.171 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -228,11 +228,6 @@ proc Initialise {} {
     set zWList {}
     set zWClose {}
     set zWInc 30000
-    InitConsts
-#
-    set inexp1 {^([^ ]*) ([^ ]*)(( ([^:][^ ]*))*)( :(.*))?$}
-    set inexp2 {^([^ ]*) ([^ ]*)(.*)?$}
-    array set ztrans {ok OK cancel Cancel}
 #
     array set zircon [set zbase {
 	nameCount 0
@@ -274,8 +269,15 @@ Continue?}]} {
     rename grab sys_grab
     proc grab {args} {if {![catch {eval sys_grab $args} res]} { return $res } }
 #
-    InitClasses
+# Must initialise classes *before* consts as some initialisation
+# currently depends on some Class values.
 #
+    InitClasses
+    InitConsts
+#
+    set inexp1 {^([^ ]*) ([^ ]*)(( ([^:][^ ]*))*)( :(.*))?$}
+    set inexp2 {^([^ ]*) ([^ ]*)(.*)?$}
+    array set ztrans {ok OK cancel Cancel}
     dispAd "Initialising bindings..."
     foreach ty {Entry Text Button} {
 	foreach x [bind $ty] { bind $ty $x {+ notIdle %W} }
@@ -626,3 +628,21 @@ proc closeWindows {} {
     foreach x $zWList {$x inactive -$zWInc}
     set zWClose [after $zWInc closeWindows]
 }
+#
+proc checkMainClose {} {
+    global zWClose zWInc zWList
+    set val 0
+    foreach x $zWList {
+        if {[$x closetime] != 0} {
+	    if {$val == 0 || [$x closetime] < $val} {
+	        set val [$x closetime]
+	    }
+	}
+    }
+    if {$val <= 0} {
+        set zWInc 30000
+    } {
+        set zWInc [expr {$val - 2000}]
+    }
+}
+
