@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/misc2.tcl,v $
-# $Date: 1998/06/13 20:35:44 $
-# $Revision: 1.18.1.38 $
+# $Date: 1998/06/25 10:55:57 $
+# $Revision: 1.18.1.39 $
 #
 #
 package provide zircon 1.18
@@ -405,7 +405,15 @@ proc ircII_/SENDLINE {net chid arg} { sillyPerson $net }
 #
 proc ircII_/SERVER {net chid arg} {
     set sv [Server :: make $net [lindex $arg 0]]
-    if {[set port [lindex $arg 1]] != {}} { $sv configure -port $port }
+    switch -regexp -- [set p [lindex $arg 1]] {
+      {} {}
+      {^[0-9]+$} { $sv configure +port $p }
+      default {
+	    tellError {} [trans port] {Port number must be numeric!}
+	    return
+	}
+    }
+    switch {} [set p [lindex $arg 2]] {} default { $sv configure -passwd $p }
     $net changeServer $sv
 }
 #
